﻿"""
/***************************************************************************
Name			 	 : Hotlink plugin
Description          : Triggers actions on single click
Date                 : 24/Jun/11 
copyright            : (C) 2011 by AEAG
email                : xavier.culos@eau-adour-garonne.fr 
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
 
"""
# Import the PyQt and QGIS libraries
import os
from PyQt4.QtCore import * 
from PyQt4.QtGui import *
from qgis.core import *

# Initialize Qt resources from file resources.py
import resources

from HotlinkMT import HotlinkMT

try:
    _fromUtf8 = QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Hotlink: 
  """Hotlink - main class
  """
  
  def __init__(self, iface):
    """Plugin Initialization
    
    @param iface Interface QGis
    """
    
    # Save reference to the QGIS interface
    self.iface = iface
    self.toolBar = None
    self.act_hotlink = None
    self.__mapTool = None
    self.__oldMapTool = None
    self.canvas = self.iface.mapCanvas()
    self.active = False

  def initGui(self):  
    """Tool bar init
    """
    
    self.toolBar = self.iface.pluginToolBar()
    self.act_hotlink = QAction(QIcon(":plugins/Hotlink/hotlink.png"),  _fromUtf8("Hotlink"),  self.iface.mainWindow())
    
    self.act_hotlink.setCheckable(True)
    self.toolBar.addAction(self.act_hotlink)
    # Activate on button pressed
    QObject.connect(self.act_hotlink, SIGNAL("triggered()"),  self.do_hotlink)

  def unload(self):
    """Remove action
    """
    self.toolBar.removeAction(self.act_hotlink)

  def do_hotlink(self): 
    """Activate/Deactivate plugin
    """

    self.active = not self.active
    
    if not self.active:
        self.deactivate()
        return

    # tool init (HotlinkMT)
    self.__oldMapTool = self.canvas.mapTool()
    self.canvas.unsetMapTool(self.canvas.mapTool())
    self.__mapTool = HotlinkMT(self)
    self.canvas.setMapTool(self.__mapTool)
    self.canvas.setCursor(QCursor(Qt.ArrowCursor))
    self.canvas.setFocus(Qt.OtherFocusReason)
        
    # others plugisn deactivation
    QObject.connect(self.canvas, SIGNAL("mapToolSet(QgsMapTool*)"), self.deactivate)

  def deactivate(self):
    """Plugin deactivation
    """
    
    self.active = False
    
    QObject.disconnect(self.canvas, SIGNAL("mapToolSet(QgsMapTool*)"), self.deactivate)
    self.act_hotlink.setChecked(False)
    self.canvas.unsetMapTool(self.__mapTool)
    self.canvas.setMapTool(self.__oldMapTool)
    self.canvas.setToolTip("")
    
    del self.__mapTool
        